@@ -3,13 +3,14 @@ package PDF::Builder::Resource::Font::CoreFont::georgia;
 use strict;
 use warnings;
 
-our $VERSION = '3.019'; # VERSION
-my $LAST_UPDATE = '3.018'; # manually update whenever code is changed
+our $VERSION = '3.028'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 =head1 NAME
 
-PDF::Builder::Resource::Font::CoreFont::georgia - font-specific information for regular Georgia font
-(I<not> standard PDF core)
+PDF::Builder::Resource::Font::CoreFont::georgia - Font-specific information for regular Georgia font
+
+I<Not> a standard PDF core font
 
 =cut
 
